@@ -4,9 +4,9 @@
 /*!
   \file
   \brief ixA]w肵➑̂̐
-  
+
   \author Satofumi KAMIMURA
-  
+
   $Id$
 */
 
@@ -47,7 +47,7 @@ enum MtrDirSettings {
 #endif
 
 
-#include "cpp_extern_macro.h"
+//#include "cpp_extern_macro.h"
 BEGIN_C_DECLS;
 
 extern void initBodyInfo(bodyInfo_t *body,
