@@ -42,10 +42,15 @@ typedef struct {
   long straight_cnt_vel;
   long rotate_cnt_vel;
 
+  long adjust_base;
+  long adjust_current_cnt;
+  long adjust_cnt;
+  long adjust_max;
+
 } bodyPosition_t;
 
 
-#include "cpp_extern_macro.h"
+//#include "cpp_extern_macro.h"
 BEGIN_C_DECLS;
 
 extern void initBodyPositionInfo(bodyPosition_t *bodyPos,
