@@ -10,7 +10,7 @@
   $Id$
 */
 
-#include "robotParams.h"
+//#include "robotParams.h"
 #include "velocityInfo.h"
 
 #ifndef MM_STABLE_SHIFT
@@ -41,7 +41,7 @@ typedef struct {
 } velocityCtrlInfo_t;
 
 
-#include "cpp_extern_macro.h"
+//#include "cpp_extern_macro.h"
 BEGIN_C_DECLS;
 
 extern void initVelocityCtrlInfo(velocityCtrlInfo_t *velCtrl);
