@@ -27,7 +27,7 @@ enum {
 };
 
 
-#include "cpp_extern_macro.h"
+//#include "cpp_extern_macro.h"
 BEGIN_C_DECLS;
 
 extern void set_imask(int mask);
